# Generated by Django 4.2.15 on 2024-08-29 07:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0002_anonymizedimagelabel_anonymousimageannotation_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='anonymousimageannotation',
            name='original_image_url',
            field=models.CharField(default='https://example.com/placeholder.jpg', max_length=255),
        ),
        migrations.AddField(
            model_name='anonymousimageannotation',
            name='processed',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='droppedname',
            name='box_coordinates',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='anonymousimageannotation',
            name='comments',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='anonymousimageannotation',
            name='label',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.anonymizedimagelabel'),
        ),
    ]
